@@ -87,15 +87,15 @@ class HourSelectionHelpers:
         ret = {}
         for idx, val in enumerate(input):
             ret[idx] = val
-        try:
-            if 23 <= len(ret) <= 24:
-                return ret
-            elif len(ret) == 25:
-                _LOGGER.debug(f"Looks like we are heading into DST. re-parsing hours")
-                input.pop(2)
-                return HourSelectionHelpers._create_dict(input)
-        except Exception as e:
-            _LOGGER.exception(f"Could not create dictionary from pricelist: {input}. Message: {e}")
+        print(len(ret))
+        if 23 <= len(ret) <= 24:
+            return ret
+        elif len(ret) == 25:
+            _LOGGER.debug(f"Looks like we are heading into DST. re-parsing hours")
+            input.pop(2)
+            return HourSelectionHelpers._create_dict(input)
+        else:
+            _LOGGER.exception(f"Could not create dictionary from pricelist: {input} with len {len(ret)}.")
             raise ValueError
         
 
