@@ -3,7 +3,7 @@ from .power_reading import PowerReading
 from .energy_weekly import EnergyWeekly
 
 class SessionPrice:
-    def __init__(self) -> None:
+    def __init__(self, init_average_data = None) -> None:
         self._total_price: int = 0
         self._price: int = 0
         self._current_power: int = 0
@@ -11,7 +11,7 @@ class SessionPrice:
         self._current_time: int = 0
         self._time_delta: int = 0
         self._readings: list = []
-        self.average_data = EnergyWeekly()
+        self.average_data = EnergyWeekly(init_average_data)
 
     @property
     def energy_average(self) -> float:
